(function() {
	/**
	 * 插槽支持
	 * @param VNode
	 * @param children
	 * @param host
	 */
	function slotSupport(VNode, children, host) {
		var slots = {
			default: []
		};

		var dfsScope = function dfsScope(node) {
			if (node.nodeName === "text" && node.attributes) {
				var text = node.children[0];
				if (
					node.attributes.scoped ||
					(typeof text === "string" && text.startsWith("[[") && text.endsWith("]]"))
				) {
					var path = text.replace(/[\[\]]/g, "").split(/[.[]/);
					if (node.attributes.scoped) {
						path = node.attributes.scoped;
					} else {
						node.attributes.scoped = path;
					}
					var data = host;
					path.forEach(function(p) {
						return (data = data[p]);
					});
					node.children[0] = JSON.stringify(data);
				}
			}

			if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfsScope);
			}
		};

		children.forEach(function(node) {
			if (node) {
				if (
					node.nodeName === "template" &&
					node.attributes &&
					node.attributes._slot
				) {
					var slotInfo = node.attributes._slot.split(":");
					if (slotInfo.length === 2) {
						node.attributes.scope = slotInfo[1];
						node.attributes._slot = slotInfo[0];
					}
					slots[node.attributes._slot] = node;
				} else {
					slots.default.push(node);
				}
				dfsScope(node);
			}
		});

		if (Object.keys(slots).length === 1 && slots.default.length === 0) {
			// 没有 slot 项目 直接返回 不要再去查找组件
			return VNode;
		}

		var dfs = function dfs(node) {
			if (node.attributes && node.attributes._slot) {
				if (slots[node.attributes._slot]) {
					if (node.attributes._slot === "default") {
						node.children = [].concat(node.children, slots[node.attributes._slot]);
					} else {
						node.children = slots[node.attributes._slot].children;
						node.attributes = Object.assign(
							slots[node.attributes._slot].attributes,
							node.attributes
						);
					}
				}
				// delete node.attributes._slot;
			} else if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfs);
			}
		};
		dfs(VNode);

		return VNode;
	}

	/**
	 * 继承父组件的 class 、style
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function extendsClassStyle(VNode, props) {
		props.class && (VNode.attributes.class += " " + props.class);
		props.style && (VNode.attributes.style = props.style);
		return VNode;
	}

	/**
	 * 超级节点
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function superNode(VNode, props) {
		slotSupport(VNode, props.children);
		extendsClassStyle(VNode, props);
		// extendsEvent(VNode, props);
		// console.log('superNode', VNode)
		return VNode;
	}

	/**
	 * 通用api.openWin打开页面
	 * @param to
	 * @param title 标题
	 * @returns {*}
	 */
	function linkTo(to, title) {
		var options = {};
		if (typeof to === "string") {
			if (to.endsWith(".stml")) {
				options.name =
					title ||
					to
						.split("/")
						.pop()
						.replace(".stml", "");
				options.url = to;
			} else if (to.endsWith(".js")) {
				options.name =
					title ||
					to
						.split("/")
						.pop()
						.replace(".js", "");
				options.url = to;
			} else {
				options.name = title || to;
				options.url = "../" + to + "/" + to + ".stml";
			}
		} else {
			options = to;
		}

		if (!options.bgColor) options.bgColor = "#FFF";

		console.log(["a-link:to", JSON.stringify(options)]);
		return api.openWin(options);
	}

	var ALink = /*@__PURE__*/ (function(Component) {
		function ALink(props) {
			Component.call(this, props);
		}

		if (Component) ALink.__proto__ = Component;
		ALink.prototype = Object.create(Component && Component.prototype);
		ALink.prototype.constructor = ALink;
		ALink.prototype.install = function() {
			this.render = function(props) {
				var VNode = props.children[0];
				VNode.attributes.onClick = function(_) {
					return linkTo(props.to, props.title);
				};
				return props.children[0];
			};
		};
		ALink.prototype.render = function() {
			return;
		};

		return ALink;
	})(Component);
	apivm.define("a-link", ALink);

	var AIcon = /*@__PURE__*/ (function(Component) {
		function AIcon(props) {
			Component.call(this, props);
		}

		if (Component) AIcon.__proto__ = Component;
		AIcon.prototype = Object.create(Component && Component.prototype);
		AIcon.prototype.constructor = AIcon;
		AIcon.prototype.install = function() {
			console.log(
				"[a-icon提示]:本组件是一个临时过渡方案。现在已经有更成熟、更自由、性能更好的 [a-iconfont] 方案。\n" +
					"          本组件是基于后端渲染实现，线上服务将于 2022 年 12 月 31 日 停止。 项目中有使用到的建议迁移到[a-iconfont] 组件，或者后端私有部署。\n" +
					"          私有部署源码参考：https://github.com/YangYongAn/icon.yangyongan.com"
			);

			this.render = function(props) {
				if (!props.size) {
					props.size = 16;
				}
				if (!props.scale) {
					props.scale = 2;
				} //2倍缩放 适配高分屏
				if (!props.color) {
					props.color = "#666";
				}
				props.color = props.color.replace("#", "_");

				var isImage = props.name.includes("/");

				var src = isImage
					? props.name
					: "http://icon.yangyongan.com/?name=" +
					  props.name +
					  "&color=" +
					  props.color +
					  "&size=" +
					  props.size +
					  "&scale=" +
					  props.scale;

				var h = apivm.h;

				var renderIcon = h(
					"img",
					Object.assign({}, props, {
						class:
							"a-icon a-icon__" +
							(isImage ? "image" : props.name) +
							" " +
							(props.class || ""),
						style:
							"width:" +
							props.size +
							"px;height:" +
							props.size +
							"px;" +
							(props.style || ""),
						src: src
					})
				);

				if (props.dot) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__dot"
						},
						renderIcon,
						h("view", {class: "a-icon__dot"})
					);
				} else if (props.badge) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__badge"
						},
						renderIcon
					);
				} else {
					return renderIcon;
				}
			};
		};
		AIcon.prototype.render = function() {
			return;
		};

		return AIcon;
	})(Component);
	AIcon.css = {
		".a-icon": {alignSelf: "center"},
		".a-icon__dot": {
			width: "8px",
			minWidth: "0",
			height: "8px",
			backgroundColor: "#ee0a24",
			borderRadius: "100%"
		}
	};
	apivm.define("a-icon", AIcon);

	var ANavBar = /*@__PURE__*/ (function(Component) {
		function ANavBar(props) {
			Component.call(this, props);
		}

		if (Component) ANavBar.__proto__ = Component;
		ANavBar.prototype = Object.create(Component && Component.prototype);
		ANavBar.prototype.constructor = ANavBar;
		ANavBar.prototype.install = function() {
			api.setStatusBarStyle &&
				api.setStatusBarStyle({
					style: "dark",
					color: "-"
				});
		};
		ANavBar.prototype.leftClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			if (this.props["onClick-left"]) {
				this.fire("click-left", ev);
			} else {
				api.closeWin();
			}
		};
		ANavBar.prototype.rightClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			this.fire("click-right", ev);
		};
		ANavBar.prototype.titleClick = function(ev) {
			this.fire("title-right", ev);
		};
		ANavBar.prototype.render = function() {
			return superNode(
				apivm.h(
					"safe-area",
					{
						class: "a-nav-bar" + (!this.props["hide-line"] ? " a-nav-bar--line" : "")
					},
					apivm.h(
						"view",
						{
							class: "a-nav-bar__content",
							style: "height: " + (this.props["height"] || 46) + "px"
						},

						this.props["left-arrow"]
							? apivm.h(
									"view",
									{
										class: "a-nav-bar__click-warp a-nav-bar__left",
										_slot: "left",
										onClick: this.leftClick
									},
									this.props["left-arrow"] &&
										apivm.h(AIcon, {
											name: "arrow-left",
											class: "a-nav-bar__icon",
											color: "#333"
										}),
									this.props["left-text"] &&
										apivm.h("text", {class: "a-nav-bar__text"}, this.props["left-text"])
							  )
							: null,

						apivm.h(
							"text",
							{
								class: "a-nav-bar__title",
								style:
									"font-size: " +
									(this.props["title-size"] || 16) +
									"px;color: " +
									(this.props["title-color"] || "#000") +
									";",
								onClick: this.titleClick
							},
							this.props["title"]
						),

						apivm.h(
							"view",
							{
								class: "a-nav-bar__click-warp a-nav-bar__right",
								_slot: "right",
								onClick: this.rightClick
							},
							apivm.h("text", {class: "a-nav-bar__text"}, this.props["right-text"])
						)
					)
				),
				this.props
			);
		};

		return ANavBar;
	})(Component);
	ANavBar.css = {
		".a-nav-bar": {backgroundColor: "#fff"},
		".a-nav-bar--line": {boxShadow: "1px 1px 1px #e6e6e6", marginBottom: "2px"},
		".a-nav-bar__content": {flexFlow: "row nowrap"},
		".a-nav-bar__click-warp": {
			position: "absolute",
			height: "100%",
			flexFlow: "row nowrap",
			alignItems: "center",
			padding: "0 16px",
			zIndex: "99"
		},
		".a-nav-bar__left": {left: "0"},
		".a-nav-bar__right": {right: "0"},
		".a-nav-bar__text": {color: "#333", fontSize: "14px"},
		".a-nav-bar__icon": {height: "16px", width: "16px"},
		".a-nav-bar__title": {
			display: "flex",
			justifyContent: "center",
			alignItems: "center",
			flex: "1",
			alignSelf: "center",
			textAlign: "center",
			fontWeight: "500",
			whiteSpace: "nowrap",
			textOverflow: "ellipsis",
			overflow: "hidden"
		}
	};
	apivm.define("a-nav-bar", ANavBar);

	var Main = /*@__PURE__*/ (function(Component) {
		function Main(props) {
			Component.call(this, props);
		}

		if (Component) Main.__proto__ = Component;
		Main.prototype = Object.create(Component && Component.prototype);
		Main.prototype.constructor = Main;
		Main.prototype.installed = function() {
			api.setStatusBarStyle &&
				api.setStatusBarStyle({
					style: "dark",
					color: "-"
				});
		};
		Main.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},

				apivm.h(
					"safe-area",
					{class: "header"},
					apivm.h("text", {class: "logo"}, "ACT")
				),
				apivm.h(
					"scroll-view",
					{class: "main", "scroll-y": true},
					apivm.h("text", {class: "desc"}, "AVM Component & Template."),
					apivm.h(
						"view",
						null,
						apivm.h("text", {class: "title"}, "基础组件"),

						apivm.h(
							ALink,
							{to: "simple-button"},
							apivm.h(
								"view",
								{class: "link"},
								apivm.h("text", {class: "com-name"}, "Button 按钮"),
								apivm.h(AIcon, {name: "arrow-right"})
							)
						),

						apivm.h(
							ALink,
							{to: "simple-cell"},
							apivm.h(
								"view",
								{class: "link"},
								apivm.h("text", {class: "com-name"}, "Cell 单元格"),
								apivm.h(AIcon, {name: "arrow-right"})
							)
						),

						apivm.h(
							ALink,
							{to: "simple-icon"},
							apivm.h(
								"view",
								{class: "link"},
								apivm.h("text", {class: "com-name"}, "Icon 图标"),
								apivm.h(AIcon, {name: "arrow-right"})
							)
						),
						apivm.h(
							ALink,
							{to: "simple-iconfont"},
							apivm.h(
								"view",
								{class: "link"},
								apivm.h("text", {class: "com-name"}, "Iconfont 图标解决方案"),
								apivm.h(AIcon, {name: "arrow-right"})
							)
						),

						apivm.h(
							"view",
							{
								class: "link",
								onClick: function(_) {
									return api.toast({msg: "该组件请暂时使用引擎提供的基础组件代替"});
								}
							},
							apivm.h("text", {class: "com-name"}, "Image 图片")
						)
					),

					apivm.h(
						ALink,
						{to: "simple-layout"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Layout 布局"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h(
						ALink,
						{to: "simple-popup"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Popup 弹出层"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h(
						ALink,
						{to: "simple-toast"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Toast 轻提示"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h("text", {class: "title"}, "表单组件"),

					apivm.h(
						ALink,
						{to: "simple-calendar"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Calendar 日历"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-field"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Field 输入框"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-search"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Search 搜索"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-stepper"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Stepper 步进器"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h("text", {class: "title"}, "展示组件"),
					apivm.h(
						ALink,
						{to: "simple-amount"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Amount 金融数字"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-badge"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Badge 徽标"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-count-down"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "CountDown 倒计时"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-divider"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Divider 分割线"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-empty"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Empty 空状态"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-skeleton"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Skeleton 骨架屏"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-tag"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Tag 标签"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h("text", {class: "title"}, "反馈组件"),

					apivm.h(
						ALink,
						{to: "simple-pull-refresh"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "PullRefresh 下拉刷新"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h(
						ALink,
						{to: "simple-share-sheet"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "ShareSheet 分享面板"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h("text", {class: "title"}, "导航组件"),

					apivm.h(
						ALink,
						{to: "simple-nav-bar"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "NavBar 导航栏"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h(
						ALink,
						{to: "simple-grid"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Grid 宫格"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),
					apivm.h(
						ALink,
						{to: "simple-tab"},
						apivm.h(
							"view",
							{class: "link"},
							apivm.h("text", {class: "com-name"}, "Tab 标签页"),
							apivm.h(AIcon, {name: "arrow-right"})
						)
					),

					apivm.h("view", {style: "height: 36px;"})
				)
			);
		};

		return Main;
	})(Component);
	Main.css = {
		".page": {height: "100%", backgroundColor: "#FFF"},
		".main": {flex: "1", padding: "0 16px", boxSizing: "border-box"},
		".header": {margin: "0 20px"},
		".logo": {
			color: "#93b920",
			fontSize: "36px",
			fontWeight: "900",
			fontFamily: "monospace",
			textShadow: "0 0 2px #999, -2px 2px 3px #000",
			marginTop: "20px"
		},
		".desc": {fontSize: "14px", color: "#999", fontStyle: "italic"},
		".title": {
			margin: "24px 0 8px 16px",
			color: "rgba(69, 90, 100, 0.6)",
			fontSize: "14px"
		},
		".link": {
			flexFlow: "row nowrap",
			margin: "0 0 12px",
			padding: "0 20px",
			background: "#f7f8fa",
			WebkitTransition: "background 0.3s",
			transition: "background 0.3s",
			height: "40px",
			border: "1px solid #f7f8fa",
			borderRadius: "20px",
			alignItems: "center"
		},
		".com-name": {
			fontSize: "14px",
			lineHeight: "40px",
			color: "#323233",
			fontWeight: "600",
			flex: "1"
		}
	};
	apivm.define("main", Main);
	apivm.render(apivm.h("main", null), "body");
})();
