(function() {
	/**
	 * 快捷 toast
	 * @param msg
	 * @param location
	 * @param duration
	 * @returns {*}
	 * @constructor
	 */
	function Toast(msg, location, duration) {
		if (location === void 0) {
			location = "middle";
		}
		if (duration === void 0) {
			duration = 1500;
		}
		if (typeof msg === "string") {
			api.toast({
				msg: msg,
				location: location,
				duration: duration
			});
		} else {
			api.toast({
				msg: msg.message,
				location: msg.position,
				duration: msg.duration
			});
		}
	}

	Toast.loading = function(options) {
		if (
			Object.keys(options).find(function(k) {
				return ["message", "forbidClick", "position"].includes(k);
			})
		) {
			api.showProgress({
				title: "",
				text: options.message,
				modal: options.forbidClick,
				location: options.position
			});
		} else {
			api.showProgress(options);
		}
	};

	Toast.clear = api.hideProgress;

	var ATab = /*@__PURE__*/ (function(Component) {
		function ATab(props) {
			Component.call(this, props);
		}

		if (Component) ATab.__proto__ = Component;
		ATab.prototype = Object.create(Component && Component.prototype);
		ATab.prototype.constructor = ATab;
		ATab.prototype.install = function() {
			this.render = function(props) {
				return props.children;
			};
		};
		ATab.prototype.render = function() {
			return;
		};

		return ATab;
	})(Component);
	apivm.define("a-tab", ATab);

	/**
	 * 插槽支持
	 * @param VNode
	 * @param children
	 * @param host
	 */
	function slotSupport(VNode, children, host) {
		var slots = {
			default: []
		};

		var dfsScope = function dfsScope(node) {
			if (node.nodeName === "text" && node.attributes) {
				var text = node.children[0];
				if (
					node.attributes.scoped ||
					(typeof text === "string" && text.startsWith("[[") && text.endsWith("]]"))
				) {
					var path = text.replace(/[\[\]]/g, "").split(/[.[]/);
					if (node.attributes.scoped) {
						path = node.attributes.scoped;
					} else {
						node.attributes.scoped = path;
					}
					var data = host;
					path.forEach(function(p) {
						return (data = data[p]);
					});
					node.children[0] = JSON.stringify(data);
				}
			}

			if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfsScope);
			}
		};

		children.forEach(function(node) {
			if (node) {
				if (
					node.nodeName === "template" &&
					node.attributes &&
					node.attributes._slot
				) {
					var slotInfo = node.attributes._slot.split(":");
					if (slotInfo.length === 2) {
						node.attributes.scope = slotInfo[1];
						node.attributes._slot = slotInfo[0];
					}
					slots[node.attributes._slot] = node;
				} else {
					slots.default.push(node);
				}
				dfsScope(node);
			}
		});

		if (Object.keys(slots).length === 1 && slots.default.length === 0) {
			// 没有 slot 项目 直接返回 不要再去查找组件
			return VNode;
		}

		var dfs = function dfs(node) {
			if (node.attributes && node.attributes._slot) {
				if (slots[node.attributes._slot]) {
					if (node.attributes._slot === "default") {
						node.children = [].concat(node.children, slots[node.attributes._slot]);
					} else {
						node.children = slots[node.attributes._slot].children;
						node.attributes = Object.assign(
							slots[node.attributes._slot].attributes,
							node.attributes
						);
					}
				}
				// delete node.attributes._slot;
			} else if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfs);
			}
		};
		dfs(VNode);

		return VNode;
	}

	/**
	 * 继承父组件的 class 、style
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function extendsClassStyle(VNode, props) {
		props.class && (VNode.attributes.class += " " + props.class);
		props.style && (VNode.attributes.style = props.style);
		return VNode;
	}

	/**
	 * 超级节点
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function superNode(VNode, props) {
		slotSupport(VNode, props.children);
		extendsClassStyle(VNode, props);
		// extendsEvent(VNode, props);
		// console.log('superNode', VNode)
		return VNode;
	}

	/**
	 * v-model 双向绑定模拟
	 * @returns {{}}
	 */
	function syncModel() {
		var $model = {};
		var _host = this._host;
		Object.entries(this.props).forEach(function(_ref3) {
			var k = _ref3[0],
				v = _ref3[1];
			if (k.startsWith("$")) {
				var path = v.replace(/]/g, "").split(/[.[]/);
				while (typeof _host.data[path[0]] === "undefined") {
					if (_host._host) {
						_host = _host._host;
					} else {
						break;
					}
				}
				var data = _host.data;
				var lastKey = path.pop();
				path.forEach(function(p) {
					return (data = data[p]);
				});
				// $model[k.substr(1)] = value => {
				//     return value === undefined ? data[lastKey] : data[lastKey] = value;
				// };

				Object.defineProperty($model, k.substr(1), {
					get: function get() {
						return data[lastKey];
					},
					set: function set(v) {
						return (data[lastKey] = v);
					}
				});
			}
		});
		this.$model = $model;
	}

	var ATabs = /*@__PURE__*/ (function(Component) {
		function ATabs(props) {
			Component.call(this, props);
			this.data = {
				// current: 0
			};
		}

		if (Component) ATabs.__proto__ = Component;
		ATabs.prototype = Object.create(Component && Component.prototype);
		ATabs.prototype.constructor = ATabs;
		ATabs.prototype.install = function() {
			var this$1 = this;

			var ns = "a-tabs";
			syncModel.call(this);
			this.breakpoint = this.props.breakpoint || 5;

			var isScroll = this.props.children.length > this.breakpoint;
			var scrollCls = function(pos) {
				return ns + "__" + pos + "--" + (isScroll ? "scroll" : "flat");
			};
			this.render = function(props) {
				this$1.current = this$1.$model.active || 0;
				var h = apivm.h;
				var type = props.type;
				if (type === void 0) type = "line";
				return h(
					"view",
					{
						class: ns + " " + ns + "--" + type + " " + (props.class || ""),
						style: props.style
					},
					h(
						isScroll ? "scroll-view" : "view",
						{
							class:
								ns + "__wrap  " + ns + "__wrap--" + type + " " + scrollCls("wrap"),
							"scroll-x": true,
							"scroll-y": false
						},

						props.children.map(function(child, index) {
							var navProps = {
								class:
									ns +
									"__nav " +
									scrollCls("nav") +
									"  " +
									ns +
									"__nav--" +
									type +
									" " +
									ns +
									"__nav--" +
									type +
									"--" +
									(index === props.children.length - 1 ? "last" : "not-last") +
									" " +
									(parseInt(this$1.current) === index
										? ns + "__nav--active--" + type
										: ns + "__nav--normal--" + type),
								onclick: this$1.onclick.bind(this$1, index)
							};

							if (isScroll) {
								navProps.style =
									"width:" + api.winWidth / this$1.breakpoint + "px;flex-shrink:0;";
							}

							return h("text", navProps, child.attributes.title);
						})
					),

					h(
						"swiper",
						{
							class: ns + "__content",
							onchange: this$1.onchange,
							current: this$1.current
						},

						props.children.map(function(child, index) {
							return h(
								"swiper-item",
								{
									class: ns + "__pane"
								},
								child
							);
						})
					)
				);
			};
		};
		ATabs.prototype.onchange = function(ref) {
			var current = ref.detail.current;

			this.fire("change", {current: current, type: "swiper"});
			this.current = current;
			this.$model.active = current;
			this.update();
			if (current >= this.breakpoint - 1) {
				this.setNavPos();
			}
		};
		ATabs.prototype.onclick = function(current) {
			var this$1 = this;

			var _run = function() {
				this$1.fire("change", {current: current, type: "click"});
				this$1.current = current;
				this$1.$model.active = current;
				this$1.update();
			};

			if (this.props["before-change"]) {
				var result = this.props["before-change"](current);

				var _run$1 = function(_) {
					return _ && _run();
				};

				result.then ? result.then(_run$1) : _run$1(result);
			} else {
				_run();
			}
		};
		ATabs.prototype.setNavPos = function() {
			api.toast({
				msg: "调整Nav位置逻辑等待外形查询功能后完善"
			});
		};
		ATabs.prototype.render = function() {
			return;
		};

		return ATabs;
	})(Component);
	ATabs.css = {
		".a-tabs--line": {background: "#FFF"},
		".a-tabs--card": {background: "transparent"},
		".a-tabs__wrap": {flexFlow: "row nowrap", alignItems: "center"},
		".a-tabs__wrap--line": {},
		".a-tabs__wrap--scroll": {display: "flex !important"},
		".a-tabs__wrap--card": {
			height: "32px",
			margin: "0 16px",
			border: "1px solid #ee0a24",
			borderRadius: "2px"
		},
		".a-tabs__nav": {textAlign: "center", fontSize: "14px"},
		".a-tabs__nav--line": {height: "44px", lineHeight: "44px"},
		".a-tabs__nav--card": {height: "30px", lineHeight: "30px"},
		".a-tabs__nav--scroll": {whiteSpace: "nowrap"},
		".a-tabs__nav--flat": {flex: "1"},
		".a-tabs__nav--normal--line": {color: "#666", fontWeight: "normal"},
		".a-tabs__nav--active--line": {color: "#333", fontWeight: "bold"},
		".a-tabs__nav--normal--card": {color: "#ee0a24", backgroundColor: "#fff"},
		".a-tabs__nav--active--card": {
			color: "#fff",
			backgroundColor: "#ee0a24",
			borderRight: "none"
		},
		".a-tabs__nav--card--last": {borderRight: "none"},
		".a-tabs__nav--card--not-last": {borderRight: "1px solid #ee0a24"},
		".a-tabs__content": {flex: "1", minHeight: "100px"},
		".a-tabs__pane": {flex: "1", padding: "24px 20px"}
	};
	apivm.define("a-tabs", ATabs);

	var AIcon = /*@__PURE__*/ (function(Component) {
		function AIcon(props) {
			Component.call(this, props);
		}

		if (Component) AIcon.__proto__ = Component;
		AIcon.prototype = Object.create(Component && Component.prototype);
		AIcon.prototype.constructor = AIcon;
		AIcon.prototype.install = function() {
			console.log(
				"[a-icon提示]:本组件是一个临时过渡方案。现在已经有更成熟、更自由、性能更好的 [a-iconfont] 方案。\n" +
					"          本组件是基于后端渲染实现，线上服务将于 2022 年 12 月 31 日 停止。 项目中有使用到的建议迁移到[a-iconfont] 组件，或者后端私有部署。\n" +
					"          私有部署源码参考：https://github.com/YangYongAn/icon.yangyongan.com"
			);

			this.render = function(props) {
				if (!props.size) {
					props.size = 16;
				}
				if (!props.scale) {
					props.scale = 2;
				} //2倍缩放 适配高分屏
				if (!props.color) {
					props.color = "#666";
				}
				props.color = props.color.replace("#", "_");

				var isImage = props.name.includes("/");

				var src = isImage
					? props.name
					: "http://icon.yangyongan.com/?name=" +
					  props.name +
					  "&color=" +
					  props.color +
					  "&size=" +
					  props.size +
					  "&scale=" +
					  props.scale;

				var h = apivm.h;

				var renderIcon = h(
					"img",
					Object.assign({}, props, {
						class:
							"a-icon a-icon__" +
							(isImage ? "image" : props.name) +
							" " +
							(props.class || ""),
						style:
							"width:" +
							props.size +
							"px;height:" +
							props.size +
							"px;" +
							(props.style || ""),
						src: src
					})
				);

				if (props.dot) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__dot"
						},
						renderIcon,
						h("view", {class: "a-icon__dot"})
					);
				} else if (props.badge) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__badge"
						},
						renderIcon
					);
				} else {
					return renderIcon;
				}
			};
		};
		AIcon.prototype.render = function() {
			return;
		};

		return AIcon;
	})(Component);
	AIcon.css = {
		".a-icon": {alignSelf: "center"},
		".a-icon__dot": {
			width: "8px",
			minWidth: "0",
			height: "8px",
			backgroundColor: "#ee0a24",
			borderRadius: "100%"
		}
	};
	apivm.define("a-icon", AIcon);

	var ANavBar = /*@__PURE__*/ (function(Component) {
		function ANavBar(props) {
			Component.call(this, props);
		}

		if (Component) ANavBar.__proto__ = Component;
		ANavBar.prototype = Object.create(Component && Component.prototype);
		ANavBar.prototype.constructor = ANavBar;
		ANavBar.prototype.install = function() {
			api.setStatusBarStyle &&
				api.setStatusBarStyle({
					style: "dark",
					color: "-"
				});
		};
		ANavBar.prototype.leftClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			if (this.props["onClick-left"]) {
				this.fire("click-left", ev);
			} else {
				api.closeWin();
			}
		};
		ANavBar.prototype.rightClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			this.fire("click-right", ev);
		};
		ANavBar.prototype.titleClick = function(ev) {
			this.fire("title-right", ev);
		};
		ANavBar.prototype.render = function() {
			return superNode(
				apivm.h(
					"safe-area",
					{
						class: "a-nav-bar" + (!this.props["hide-line"] ? " a-nav-bar--line" : "")
					},
					apivm.h(
						"view",
						{
							class: "a-nav-bar__content",
							style: "height: " + (this.props["height"] || 46) + "px"
						},

						this.props["left-arrow"]
							? apivm.h(
									"view",
									{
										class: "a-nav-bar__click-warp a-nav-bar__left",
										_slot: "left",
										onClick: this.leftClick
									},
									this.props["left-arrow"] &&
										apivm.h(AIcon, {
											name: "arrow-left",
											class: "a-nav-bar__icon",
											color: "#333"
										}),
									this.props["left-text"] &&
										apivm.h("text", {class: "a-nav-bar__text"}, this.props["left-text"])
							  )
							: null,

						apivm.h(
							"text",
							{
								class: "a-nav-bar__title",
								style:
									"font-size: " +
									(this.props["title-size"] || 16) +
									"px;color: " +
									(this.props["title-color"] || "#000") +
									";",
								onClick: this.titleClick
							},
							this.props["title"]
						),

						apivm.h(
							"view",
							{
								class: "a-nav-bar__click-warp a-nav-bar__right",
								_slot: "right",
								onClick: this.rightClick
							},
							apivm.h("text", {class: "a-nav-bar__text"}, this.props["right-text"])
						)
					)
				),
				this.props
			);
		};

		return ANavBar;
	})(Component);
	ANavBar.css = {
		".a-nav-bar": {backgroundColor: "#fff"},
		".a-nav-bar--line": {boxShadow: "1px 1px 1px #e6e6e6", marginBottom: "2px"},
		".a-nav-bar__content": {flexFlow: "row nowrap"},
		".a-nav-bar__click-warp": {
			position: "absolute",
			height: "100%",
			flexFlow: "row nowrap",
			alignItems: "center",
			padding: "0 16px",
			zIndex: "99"
		},
		".a-nav-bar__left": {left: "0"},
		".a-nav-bar__right": {right: "0"},
		".a-nav-bar__text": {color: "#333", fontSize: "14px"},
		".a-nav-bar__icon": {height: "16px", width: "16px"},
		".a-nav-bar__title": {
			display: "flex",
			justifyContent: "center",
			alignItems: "center",
			flex: "1",
			alignSelf: "center",
			textAlign: "center",
			fontWeight: "500",
			whiteSpace: "nowrap",
			textOverflow: "ellipsis",
			overflow: "hidden"
		}
	};
	apivm.define("a-nav-bar", ANavBar);

	var SimpleTab = /*@__PURE__*/ (function(Component) {
		function SimpleTab(props) {
			Component.call(this, props);
			this.data = {
				active: [2, 0]
			};
		}

		if (Component) SimpleTab.__proto__ = Component;
		SimpleTab.prototype = Object.create(Component && Component.prototype);
		SimpleTab.prototype.constructor = SimpleTab;
		SimpleTab.prototype.apiready = function() {
			console.log(this);
			this.data.active[0] = 3;
		};
		SimpleTab.prototype.onchange = function(e) {
			console.log(JSON.stringify(e));
		};
		SimpleTab.prototype.beforeChange = function(index) {
			console.log("beforeChange");
			// 返回 false 表示阻止此次切换
			if (index === 1) {
				return false;
			}

			// 返回 Promise 来执行异步逻辑
			return new Promise(function(resolve) {
				// 在 resolve 函数中返回 true 或 false

				Toast.loading({forbidClick: true, message: "正在异步请求"});

				setTimeout(function() {
					resolve(index !== 3);
					Toast.clear();
				}, 1000);
			});
		};
		SimpleTab.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h("a-nav-bar", {title: "simple-tab", "left-arrow": true}),
				apivm.h(
					"scroll-view",
					{style: "flex: 1;", "scroll-y": true},

					apivm.h(
						"view",
						{class: "simple"},
						apivm.h(
							"text",
							{class: "simple-title"},
							"基本用法 ",
							this.data.active[0]
						),

						apivm.h(
							"text",
							{class: "simple-desc"},
							"通过 $active 绑定当前激活标签对应的索引值，默认情况下启用第一个标签。"
						),

						apivm.h(
							ATabs,
							{$active: "active[0]"},
							apivm.h(ATab, {title: "标签 1"}, apivm.h("text", null, "内容 1")),
							apivm.h(ATab, {title: "标签 2"}, apivm.h("text", null, "内容 2")),
							apivm.h(ATab, {title: "标签 3"}, apivm.h("text", null, "内容 3")),
							apivm.h(ATab, {title: "标签 4"}, apivm.h("text", null, "内容 4"))
						)
					),

					apivm.h(
						"view",
						{class: "simple"},
						apivm.h("text", {class: "simple-title"}, "标签栏滚动"),

						apivm.h(
							"text",
							{class: "simple-desc"},
							"标签数量超过 5 个时，标签栏可以在水平方向上滚动，切换时会自动将当前标签居中。"
						),

						apivm.h(
							ATabs,
							{$active: "active[1]"},
							Array.from({length: 8}, function(_, i) {
								return i + 1;
							}).map(function(i) {
								return apivm.h(
									ATab,
									{title: "标签 " + i},
									apivm.h("text", null, "内容 ", i)
								);
							})
						)
					),

					apivm.h(
						"view",
						{class: "simple"},
						apivm.h("text", {class: "simple-title"}, "样式风格"),

						apivm.h(
							"text",
							{class: "simple-desc"},
							"Tab 支持两种样式风格：line 和card，默认为 line 样式，可以通过 type 属性切换样式风格。"
						),

						apivm.h(
							ATabs,
							{type: "card", onchange: this.onchange},
							apivm.h(ATab, {title: "标签 1"}, apivm.h("text", null, "内容 1")),
							apivm.h(ATab, {title: "标签 2"}, apivm.h("text", null, "内容 2")),
							apivm.h(ATab, {title: "标签 3"}, apivm.h("text", null, "内容 3"))
						)
					),

					apivm.h(
						"view",
						{class: "simple"},
						apivm.h("text", {class: "simple-title"}, "异步切换"),

						apivm.h(
							"text",
							{class: "simple-desc"},
							"通过 before-change 属性可以在切换标签前执行特定的逻辑。"
						),

						apivm.h(
							ATabs,
							{"before-change": this.beforeChange},
							Array.from({length: 4}, function(_, i) {
								return i + 1;
							}).map(function(i) {
								return apivm.h(
									ATab,
									{title: "标签 " + i},
									apivm.h("text", null, "内容 ", i)
								);
							})
						)
					)
				)
			);
		};

		return SimpleTab;
	})(Component);
	SimpleTab.css = {
		".page": {height: "100%", flex: "1", backgroundColor: "#F8F8F8"},
		".simple": {paddingBottom: "28px"},
		".simple-title": {margin: "16px", fontWeight: "600", fontSize: "18px"},
		".simple-desc": {color: "#999", fontSize: "14px", margin: "0 16px 16px"}
	};
	apivm.define("simple-tab", SimpleTab);
	apivm.render(apivm.h("simple-tab", null), "body");
})();
